@@ -24,7 +24,7 @@ class Module:
           <do thing>
 
   Arguments:
-    filepath: The file path of the module. From the derived class scope, it should be ``__file__``. The ``filepath`` arguement is used to retrieve the module *YAML* specification file.
+    filepath: The file path of the module. From the derived class scope, it should be ``__file__``. The ``filepath`` argument is used to retrieve the module *YAML* specification file.
     context: The ``laboro.context.Context`` associated with the ``laboro.workflow.Workflow`` instance instantiating the module. The ``context`` will be automatically provided by the workflow.
     args: A kwargs representing the module instance arguments.
 
@@ -57,6 +57,12 @@ class Module:
       return self.context.get(func.__name__)
     return wrapper
 
+  def __enter__(self):
+    return self
+
+  def __exit__(self, kind, value, traceback):
+    pass
+
   def _validate_spec(self):
     """Load module specification from its YAML data file."""
     base_spec = os.path.join(os.path.dirname(__file__),
