@@ -12,6 +12,10 @@ class Workflow:
   Arguments:
     name: A string representing the workflow name.
     context: A ``laboro.context.Context`` instance.
+    name: A string specifying the name of the workflow
+    packages: A list of package names.
+    workspace: A dictionary representation of a workspace configuration (see ``laboro.workspace.Workspace`` for further dertails).
+    steps: A list of dictionary representation of ``laboro.workflow.Step``
 
   Returns:
     ``laboro.workflow.Workflow``: A Workflow object.
@@ -23,26 +27,33 @@ class Workflow:
       from laboro.context import Context
       from laboro.workflow import Workflow
 
-      logmgr = LogMgr(vault=Vault())
-      context = Context(logger=logmgr)
-      with Workflow(name="my_workflow", context=context) as wkf:
+      cfg_mgr = CfgMgr(main_config="/etc/laboro/laboro.yml")
+      context = Context(logger=LogMgr(Vault()), config_mgr=cfg_mgr)
+      logging.getLogger().log_section("LABORO", "Bootstrapping")
+      logging.getLogger().vault.clear()
+      cfg_mgr.workflow_config = "my_workflow.yml"
+      workflow = cfg_mgr.workflow_config
+      with Workflow(context=context, **workflow) as wkf:
         wkf.run()
         ...
   """
-  def __init__(self, name, context):
-    self.name = name
-    self.session = str(uuid.uuid4())
-    self.ctx = context.reset(self.name, self.session)
+  def __init__(self, context, name, packages, workspace, steps):
+    self.name = name.replace(" ", "_")
+    self.packages = packages
+    self.workspace = workspace
+    self.steps = steps
+    self.ctx = context.reset(session=str(uuid.uuid4()),
+                             workspace_cfg=self.workspace)
 
   def __enter__(self):
     return self
 
   def __exit__(self, kind, value, traceback):
-    self.ctx.exit(self.name, self.session, kind, value)
+    self.ctx.exit(kind, value)
 
   def run(self):
     """Run the workflow."""
-    for wkf_step in self.ctx.configmgr.get_parameter("workflow", "$.steps"):
+    for wkf_step in self.steps:
       with Step(self.ctx, **wkf_step) as step:
         step.run()
     logging.getLogger().log_line()
